..
    Copyright (C) 2018 CERN.
    Copyright (C) 2018 RERO.
    Invenio-Circulation is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

=====================
 Invenio-Circulation
=====================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-circulation.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-circulation

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-circulation.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-circulation

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-circulation.svg
        :target: https://github.com/inveniosoftware/invenio-circulation/releases

.. image:: https://img.shields.io/pypi/dm/invenio-circulation.svg
        :target: https://pypi.python.org/pypi/invenio-circulation

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-circulation.svg
        :target: https://github.com/inveniosoftware/invenio-circulation/blob/master/LICENSE

Invenio module for the circulation of bibliographic items.

*This is an experimental developer preview release.*

TODO: Please provide feature overview of module

Further documentation is available on
https://invenio-circulation.readthedocs.io/
